@@ -1,7 +1,8 @@
 #include "anthyengine.h"
 #include "debug.h"
-#include <qobject.h>
-#include <qtextcodec.h>
+#include <QObject>
+#include <QTextCodec>
+#include <QTimerEvent>
 #include <anthy/anthy.h>
 #include <dlfcn.h>
 
@@ -72,7 +73,7 @@ AnthyEngine::init()
 
     // Version check
     QString version = (*pfget_version_string)();
-    qDebug("Anthy version: %s", version.ascii());
+    qDebug("Anthy version: %s", qPrintable(version));
     if (version >= "7100b") {
       _pf_set_prediction_string = (int(*)(void*, const char*))dlsym(_dlanthy, "anthy_set_prediction_string");
       _pf_get_prediction_stat = (int(*)(void*, struct anthy_prediction_stat*))dlsym(_dlanthy, "anthy_get_prediction_stat");
@@ -129,7 +130,7 @@ AnthyEngine::cleanup()
 bool
 AnthyEngine::beginConvert(const QString& hira, QStringList& kanji, QStringList& yomigana)
 {
-  DEBUG_TRACEFUNC("hira: %s", hira.local8Bit().data());
+  DEBUG_TRACEFUNC("hira: %s", qPrintable(hira));
   if ( !_anthy )
     return FALSE;
 
@@ -181,8 +182,8 @@ AnthyEngine::endConvert(const QStringList& kanji)
 	QStringList cand;
 	bool ok = getCandidate(i, cand);
 	if ( ok ) {
-	  int n = cand.findIndex(kanji[i]);
-	  (*_pf_commit_segment)((anthy_context_t)_anthy, i, QMAX(n, 0));
+	  int n = cand.indexOf(kanji[i]);
+	  (*_pf_commit_segment)((anthy_context_t)_anthy, i, qMax(n, 0));
 	}
       }
     }
@@ -212,7 +213,7 @@ AnthyEngine::getCandidate(int idx, QStringList& candidate)
     int len = (*_pf_get_segment)((anthy_context_t)_anthy, idx, i, buf, sizeof(buf));
     if (len > 0) {
       QString str(QObject::tr(buf));
-      if ( !str.isEmpty() && candidate.find(str) == candidate.end()) {
+      if ( !str.isEmpty() && !candidate.contains(str)) {
 	candidate << str;
       }
     }
@@ -286,7 +287,7 @@ void
 AnthyEngine::predict(const QString&, const QString& hira)
 {
 #ifdef HAS_ANTHY_PREDICTION
-  DEBUG_TRACEFUNC("hira: %s", hira.local8Bit().data());
+  DEBUG_TRACEFUNC("hira: %s", qPrintable(hira));
 
   if ( !_anthy || !_pf_set_prediction_string )
     return;
@@ -325,7 +326,7 @@ AnthyEngine::timerEvent(QTimerEvent* e)
     return;
   }
 
-  qDebug("hiragana: %s", _srcpredict.local8Bit().data());
+  qDebug("hiragana: %s", qPrintable(_srcpredict));
   int ret = (*_pf_set_prediction_string)((anthy_context_t)_anthy, QTextCodec::codecForTr()->fromUnicode(_srcpredict).data());
   if (ret < 0) {
     qWarning("error anthy_set_prediction_string");
