@@ -109,26 +109,17 @@ CandidateListBox::selectPreviousCandidate(uint decrement)
   if ( isHidden() ) {
     qFatal("Assert  %s:%d", __FILE__, __LINE__);
     return;
-  } else if ( !_lstbox->count() ) {
-    Q_ASSERT( _lstbox->count() );
-    return;
   }
 
   int prev = _lstbox->currentRow() - decrement;
   if (prev < 0) {
-    if (topItem() > 0) {
-      _lstbox->setCurrentRow(0);
-    } else {
-      _lstbox->setCurrentRow(_lstbox->count() - 1);
+    prev = _lstbox->count() - 1;  // Last candidate
+    if (decrement > 1 && (visibleTopItem() > 0 || _lstbox->count() <= MAX_VISIBLE_ITEMS)) {
+      prev = 0;  // First candidate
     }
-
-  } else {
-    if (prev < topItem()) {
-      int top = (decrement == MAX_VISIBLE_ITEMS) ? prev : prev - MAX_VISIBLE_ITEMS + 1;
-      _lstbox->scrollToItem(_lstbox->item(top), QAbstractItemView::PositionAtTop);
-    }
-    _lstbox->setCurrentRow(prev);
   }
+
+  _lstbox->setCurrentRow(prev);
 }
 
 
@@ -139,20 +130,15 @@ CandidateListBox::selectNextCandidate(uint increment)
     qFatal("Assert  %s:%d", __FILE__, __LINE__);
     return;
   }
-  if (increment > (uint)_lstbox->count()) {
-    qFatal("Assert  %s:%d", __FILE__, __LINE__);
-    return;
-  }
 
   int next = _lstbox->currentRow() + increment;
-  if (next < (int)_lstbox->count()) {
-    _lstbox->setCurrentRow(next);
-    if (next >= topItem() + MAX_VISIBLE_ITEMS) {
-      _lstbox->scrollToItem(_lstbox->item(next), QAbstractItemView::PositionAtTop);
+  if (next >= _lstbox->count()) {
+    next = 0;  // First candidate
+    if (increment > 1 && visibleBottomItem() < _lstbox->count() - 1) {
+      next = _lstbox->count() - 1;  // Last candidate
     }
-  } else {
-    _lstbox->setCurrentRow(0);
   }
+  _lstbox->setCurrentRow(next);
 }
 
 
@@ -281,15 +267,35 @@ CandidateListBox::text(int index) const
   return _lstbox->item(index)->text();
 }
 
+int
+CandidateListBox::currentItem() const
+{
+  return _lstbox->currentRow();
+}
 
 int
-CandidateListBox::topItem() const
+CandidateListBox::visibleTopItem() const
 {
   return _lstbox->row( _lstbox->itemAt(0, 0) );
 }
 
+int
+CandidateListBox::visibleBottomItem() const
+{
+  return _lstbox->row( _lstbox->itemAt(0, _lstbox->height() - 1));
+}
+
 uint
 CandidateListBox::count() const
 {
   return _lstbox->count();
 }
+
+void
+CandidateListBox::scrollToItemAtTop(int index)
+{
+  QListWidgetItem* item = _lstbox->item(index);
+  if ( item ) {
+    _lstbox->scrollToItem(item, QAbstractItemView::PositionAtTop);
+  }
+}
