@@ -437,8 +437,12 @@ CannaEngine::beginConvert(const QString& hira, QStringList& kanji, QStringList&
     return false;
   }
 
-  kanji = recvBeginConvertReply();
   yomigana.clear();
+  kanji = recvBeginConvertReply();
+  if (kanji.isEmpty()) {
+    kanji << hira;
+  }
+
   for (int i = 0; i < (int)kanji.count(); ++i) {
     QString str = getYomi(i);
     if (str.isEmpty())
@@ -499,7 +503,7 @@ CannaEngine::recvBeginConvertReply()
   }
 
   qDebug("beginConvert successful");
-  qDebug("[%s]  %s", __func__, qPrintable(strlist.join(" ")));
+  qDebug("[%s] string: %s (%d)", __func__, qPrintable(strlist.join(" ")), strlist.count());
   return strlist;
 }
 
@@ -652,7 +656,7 @@ CannaEngine::recvGetCandidateListReply()
     }    
     
     QString str = tr(uint16ToEuc(ba));
-    if ( ! listcand.contains(str) ) {
+    if (!str.isEmpty() && !listcand.contains(str)) {
       listcand << str;
     }
   }
