@@ -9,10 +9,12 @@ public:
   static QString readEntry(const QString& key, const QString& defaultval = QString());
   static bool readBoolEntry(const QString& key, bool defaultval = false);
   static int  readNumEntry(const QString& key, int defaultval = 0);
-  static void writeEntry(const QString& key, const QString& value, bool override = true);
-  static void writeEntry(const QString& key, bool value, bool override = true);
-  static void writeEntry(const QString& key, int value, bool override = true);
+  static void writeEntry(const QString& key, const QString& value, bool overwrite = true);
+  static void writeEntry(const QString& key, bool value, bool overwrite = true);
+  static void writeEntry(const QString& key, int value, bool overwrite = true);
   static QString dictionaryDirPath();
+  static QString originalDictionaryDirPath();
+  static QString imageDirPath();
 
 protected:
   static QString configDirPath();
