@@ -510,7 +510,7 @@ void
 DictHiragana::copyDictFile(const QString dicname)
 {
   DEBUG_TRACEFUNC("dicname: %s", qPrintable(dicname));
-  QString src = QString(INSTALL_PATH "/dic/") + dicname;
+  QString src = Config::originalDictionaryDirPath() + "/" + dicname;
   QString dst = Config::dictionaryDirPath() + "/" + dicname;
 
   if ( !QFile::exists(dst) ) {
@@ -521,6 +521,7 @@ DictHiragana::copyDictFile(const QString dicname)
     
     // Copies the dictionary file    
     QFile::copy(src, dst);
+    qDebug("file copy: %s -> %s", qPrintable(src), qPrintable(dst));
   }
 }
 
