@@ -3,10 +3,9 @@
 
 #include "kimeraglobal.h"
 #include "inputmode.h"
-#include <qdict.h>
-#include <qstring.h>
-#include <qevent.h>
-#include <qptrlist.h>
+#include <QString>
+#include <QKeyEvent>
+#include <QHash>
 
 class DictHiragana {
 public:
@@ -16,19 +15,19 @@ public:
   ~DictHiragana();
 
   // 
-  void     init();
+  void init();
 
   //   ߤ Ѵ
-  QString  convert(const QPtrList<QKeyEvent>& kevlst, const InputMode& mode, bool tenkey_hankaku=FALSE) const;
+  QString convert(const QList<QKeyEvent>& kevlst, const InputMode& mode, bool tenkey_hankaku=false) const;
 
   // ߤ   Ѵ  
-  void     reverse(const QString& yomi, const InputMode& mode, bool tenkey_hankaku, QPtrList<QKeyEvent>& kevlst) const;
+  void reverse(const QString& yomi, const InputMode& mode, bool tenkey_hankaku, QList<QKeyEvent>& kevlst) const;
 
   // Ҥ餬  ߤ(޻) Ѵ
   QString  convertString(const QString& hira, const InputMode& mode=InputMode()) const;
   
 protected:
-  void     initDict(QDict<QString>& dict, const QString&, bool reverse_dict=FALSE);
+  void     initDict(QHash<QString, QString>& dict, const QString&, bool reverse_dict=false);
   QString  convertKey(const QKeyEvent& key, const InputMode& mode) const;  //   ߤ Ѵ
   QString  convertToHira(const QString&) const;    // Ҥ餬Ѵ
   QString  convertToKata(const QString&) const;    // Ѵ
@@ -40,14 +39,14 @@ protected:
   static void copyDictFile(const QString dicname);
 
 private:
-  QDict<QString>     _dicthira;      // Ҥ餬ʼ
-  QDict<QString>     _dictkata;      // ʼ
-  QDict<QString>     _dicthankana;   // Ⱦѥʼ
-  QDict<QString>     _dictalphbt;    // ѱѻ
-  QDict<QString>     _dictsymbol;    // ѿ漭
-  QDict<QString>     _dictkanainp;   // ϼ
-  QDict<QString>     _dictdakuten;   // 
-  QDict<QString>     _reversedict;   // հ
+  QHash<QString, QString>   _dicthira;      // Ҥ餬ʼ
+  QHash<QString, QString>   _dictkata;      // ʼ
+  QHash<QString, QString>   _dicthankana;   // Ⱦѥʼ
+  QHash<QString, QString>   _dictalphbt;    // ѱѻ
+  QHash<QString, QString>   _dictsymbol;    // ѿ漭
+  QHash<QString, QString>   _dictkanainp;   // ϼ
+  QHash<QString, QString>   _dictdakuten;   // 
+  QHash<QString, QString>   _reversedict;   // հ  
 };
 
 #endif // DICTHIRAGANA_H
