@@ -49,8 +49,6 @@ InputMethod::InputMethod() : _cltwinstack(QStack<Window>()),
 			     _kimera_atom(0),
 			     _inputon(FALSE)
 {
-  QTimer::singleShot(0, this, SLOT(init()));
-
   _xim = new XIMethod();
   _buffer = new QBuffer();
   _buffer->open( QIODevice::WriteOnly | QIODevice::Append );
@@ -59,6 +57,8 @@ InputMethod::InputMethod() : _cltwinstack(QStack<Window>()),
   _kanjiconvt = new KanjiConvert();
 
   connect(_kanjiconvt, SIGNAL(decideSegments(const QString&)), this,  SLOT(slotDecideSegments(const QString&)));
+  // Initialize
+  QTimer::singleShot(0, this, SLOT(init()));
 }
 
 
@@ -165,7 +165,7 @@ InputMethod::recvXIMError()
 	   im, ic, flag, errcode, errtype, __FILE__, __LINE__);
   if (errlen > 0) {
     char errdetail[256] = { 0 };
-    dsbuf.readRawData((char*)errdetail, qMin((quint32)errlen, sizeof(errdetail) - 1));   // header
+    dsbuf.readRawData((char*)errdetail, qMin((quint32)errlen, (quint32)sizeof(errdetail) - 1));   // header
     qDebug("Error detail: %s", errdetail);
   }
 }
@@ -801,7 +801,7 @@ InputMethod::recvXIMDisconnect(const XEvent&)
       qDebug("XSendEvent XIM_DISCONNECT_REPLY");
     }
   } else {
-    qFatal("Bad parameter  %s:%d", __FILE__, __LINE__);
+    qWarning("Bad parameter  %s:%d", __FILE__, __LINE__);
   }
 }
 
