@@ -8,12 +8,12 @@
 
 #include "kimeraapp.h"
 #include "xicattribute.h"
-#include <qwidget.h>
-#include <qstring.h>
-#include <qptrlist.h>
-#include <qbuffer.h>
-#include <qvaluestack.h>
-#include <X11/Xlib.h>
+#include <QWidget>
+#include <QBuffer>
+#include <QStack>
+#include <QCustomEvent>
+#include <QKeyEvent>
+#include <QEvent>
 
 class XIMethod;
 class KanjiConvert;
@@ -146,7 +146,7 @@ signals:
   void  triggerNotify(bool);   // TRUE: on   FALSE: off
 
 protected:
-  void customEvent(QCustomEvent*);
+  void customEvent(QEvent*);
   void recvSelectionEvent(const QEvent* e);
   void recvSelectionRequest(const XEvent&) const;
   void recvSelectionClear(const XEvent&);
@@ -172,28 +172,28 @@ protected:
   void recvXIMSync() const;
   void recvXIMSyncReply() const;
   //void sendXIMCommit(const XKeyEvent&) const;
-  void sendXIMSetEventMask(u_int16_t im, u_int16_t ic, ulong fwrd = 0, ulong sync = 0) const;
-  void sendXIMRegisterTriggerkeys(u_int16_t im) const;
-  void sendXIMSync(u_int16_t im, u_int16_t ic) const;
-  void sendXIMError(u_int16_t im, u_int16_t ic, XIMErrorFlag flag, XIMErrorCode error) const;
+  void sendXIMSetEventMask(quint16 im, quint16 ic, quint32 fwrd = 0, quint32 sync = 0) const;
+  void sendXIMRegisterTriggerkeys(quint16 im) const;
+  void sendXIMSync(quint16 im, quint16 ic) const;
+  void sendXIMError(quint16 im, quint16 ic, XIMErrorFlag flag, XIMErrorCode error) const;
   void sendXIMError(Window client, XIMErrorCode error) const;
 
   // Callbacks
-  void sendXIMPreeditStart(u_int16_t im, u_int16_t ic) const;
+  void sendXIMPreeditStart(quint16 im, quint16 ic) const;
   void recvXIMPreeditStartReply() const;
-  void sendXIMPreeditDraw(u_int16_t im, u_int16_t ic, int caret, int index, int length, const QString& str=QString::null, const QByteArray& feedback=QByteArray()) const;
-  void sendXIMPreeditDone(u_int16_t im, u_int16_t ic) const;
+  void sendXIMPreeditDraw(quint16 im, quint16 ic, int caret, int index, int length, const QString& str=QString::null, const QByteArray& feedback=QByteArray()) const;
+  void sendXIMPreeditDone(quint16 im, quint16 ic) const;
 
   // Sends Client Message
   void sendClientMessageProtocol(Window w, XClientMessageEvent&) const;
   void sendClientMessageMoredata(Window w, XClientMessageEvent&) const;
-  void sendClientMessage(u_int16_t im, const QByteArray&) const;
-  void sendPropertywithCM(u_int16_t im, const QByteArray&) const;
+  void sendClientMessage(quint16 im, const QByteArray&) const;
+  void sendPropertywithCM(quint16 im, const QByteArray&) const;
  
-  QPoint     calcPreeditPoint(u_int16_t im, u_int16_t ic, bool& ok) const;
-  bool       checkCommWindow(u_int16_t im) const;
+  QPoint     calcPreeditPoint(quint16 im, quint16 ic, bool& ok) const;
+  bool       checkCommWindow(quint16 im) const;
   int        pad(int n) const { return (4 - (n % 4)) % 4; }
-  u_int16_t  numElements(int n) const { return (n + pad(n)) / 4; }
+  quint16  numElements(int n) const { return (n + pad(n)) / 4; }
 
   virtual void keyPressEvent(QKeyEvent*);
 
@@ -205,11 +205,11 @@ private:
   InputMethod();
   ~InputMethod();
 
-  QValueStack<Window> _cltwinstack; // current client communication window ID
-                                    //   for XTransportConnection, XIMOpen, XIMClose,
-                                    //   XIMConnect and XIMDisconnect messages.
-  u_int16_t  _crnt_im;   // current input method ID
-  u_int16_t  _crnt_ic;   // current input context ID
+  QStack<Window> _cltwinstack; // current client communication window ID
+                               //   for XTransportConnection, XIMOpen, XIMClose,
+                               //   XIMConnect and XIMDisconnect messages.
+  quint16    _crnt_im;   // current input method ID
+  quint16    _crnt_ic;   // current input context ID
   Atom       _server_atom;
   Atom       _xim_xconnect; 
   Atom       _xim_protocol; 
