@@ -841,7 +841,7 @@ KanjiConvert::decideCandidateList(int no)
   // Replace string
   QString str = _candlist->text(_candlist->visibleTopItem() + no - 1);
   if (!str.isEmpty()) {
-    replaceSegments(_crntsegidx, 1,  QStringList(str));
+    replaceSegments(_crntsegidx, 1, QStringList(str));
   }
   _candlist->hide();
   _stat = CONVERTING_YOMI;
@@ -1901,10 +1901,11 @@ KanjiConvert::caretToLast()
 void
 KanjiConvert::replaceSegments(int idx, int num, const QStringList& convseg)
 {
-  DEBUG_TRACEFUNC("list: %s  idx: %d", qPrintable(convseg.join(" ")), idx);
+  DEBUG_TRACEFUNC("idx:%d num:%d list:%s", idx, num, qPrintable(convseg.join(" ")));
   CHECK_NOCHANGE(_stat, int);
 
-  qDebug("candidacies(%d) :%s  (crnt:%d  min:%d)", convseg.count(), qPrintable(convseg.join(" ")), _crntsegidx, _minsegidx);  
+  qDebug("current kanji: %s (count:%d  crnt:%d  min:%d)", qPrintable(_convtkanjilist.join(" ")),
+         _convtkanjilist.count(), _crntsegidx, _minsegidx);  
   if (idx + num > _convtkanjilist.count()) {
     Q_ASSERT(0);
     return;
