@@ -1,7 +1,6 @@
 #include "kanjiengine.h"
-#include <qptrlist.h>
 
-static QPtrList<KanjiEngine>* enginelist = 0;
+static QList<KanjiEngine*>* enginelist = 0;
 
 
 class KanjiEngineCleanup {
@@ -12,8 +11,12 @@ public:
 
 KanjiEngineCleanup::~KanjiEngineCleanup()
 {
-  if (enginelist)
+  if (enginelist) {
+    while ( !enginelist->isEmpty() )
+      delete enginelist->takeFirst();
+
     delete enginelist;
+  }
 
   enginelist = 0;
 }
@@ -23,8 +26,7 @@ static KanjiEngineCleanup kanjienginecleanup;
 KanjiEngine::KanjiEngine()
 {
   if (!enginelist) {
-    enginelist = new QPtrList<KanjiEngine>;
-    enginelist->setAutoDelete(FALSE);
+    enginelist = new QList<KanjiEngine*>;
   }
   enginelist->append(this);
 }
@@ -69,13 +71,14 @@ KanjiEngine*
 KanjiEngine::kanjiEngine(const QString& name)
 {
   Q_ASSERT(enginelist);
-  KanjiEngine* eng;
-  for (eng = enginelist->first(); eng; eng = enginelist->next()) {
-    if (eng->name().lower() == name.lower())
-      break;
+  QListIterator<KanjiEngine*> it(*enginelist);
+  while (it.hasNext()) {
+    KanjiEngine* eng = it.next();
+    if (eng->name().toLower() == name.toLower()) {
+      return eng;
+    }
   }
-  
-  return eng;
+  return 0;
 }
 
 
@@ -83,9 +86,11 @@ QStringList
 KanjiEngine::kanjiEngineList()
 {
   QStringList lst;
-  for (KanjiEngine* eng = enginelist->first(); eng; eng = enginelist->next()) {
-    if (!eng->name().isEmpty())
-      lst << eng->name();
+  QListIterator<KanjiEngine*> it(*enginelist);
+  while (it.hasNext()) {
+    QString str = it.next()->name();
+    if ( !str.isEmpty() )
+      lst << str;
   }
   return lst;
 }
