@@ -1,11 +1,10 @@
 #include "kimeraapp.h"
-#include "mainform.h"
-#include <qtextcodec.h>
-#include <qapplication.h>
-#include <qstylefactory.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <sys/types.h>
+#include "maintoolbar.h"
+#include "style.h"
+#include <QTextCodec>
+#include <QApplication>
+#include <QDir>
+#include <QFile>
 #include <unistd.h>
 #include <pwd.h>
 
@@ -40,37 +39,29 @@ int
 main(int argc, char* argv[])
 {
   qInstallMsgHandler(outputMessage);
+  QApplication::setStyle(new Style());
   KimeraApp app(argc, argv);
 
   // Check lock file
   struct passwd* pass = getpwuid( getuid() );
   QDir::setCurrent("/tmp");
-  QFile lockfile(QString(".kimera_") + pass->pw_name + ".lock");
+  QFile lockfile(QString(".kimera_") + QString(pass->pw_name) + ".lock");
   if ( !lockfile.exists() ) {
-    qFatal("No such lock file: %s/%s", QDir::current().path().ascii(), lockfile.name().ascii());
+    qFatal("No such lock file: %s/%s", qPrintable(QDir::current().path()),
+           qPrintable(lockfile.fileName()));
     return -1;
   } else {
     lockfile.remove();
   }
 
-  // Sets style
-  qDebug("QStyle keys=%s", QStyleFactory::keys().join(":").ascii());
-  QStyle* style = QStyleFactory::create( "Plastik" );
-  if ( style ) {
-    QApplication::setStyle( style );
-  }
-  QColor color(QWidget().paletteBackgroundColor());
-  QApplication::setPalette(QPalette(color, color)); // Set default background color
-
   // Sets codec, eucJP.
   QTextCodec*  codec = QTextCodec::codecForName("eucJP");  
   Q_CHECK_PTR( codec );
-  qDebug("codec: %s", codec->name());
+  qDebug("codec: %s", codec->name().data());
   QTextCodec::setCodecForTr( codec );
 
   // Shows main widget
-  MainForm* mainwidget = new MainForm();
-  app.setMainWidget(mainwidget);
+  MainToolBar* mainwidget = new MainToolBar();
   mainwidget->move( mainwidget->loadPos() );
   mainwidget->show();    // Need to show at least once for initiation
   return app.exec();
