@@ -1,11 +1,7 @@
 #ifndef PREEDITAREA_H
 #define PREEDITAREA_H
 
-#include <qwidget.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qcolor.h>
-#include <qfont.h>
+#include <QWidget>
 
 class QLabel;
 
@@ -13,13 +9,13 @@ class PreeditArea : public QWidget {
   Q_OBJECT
 
 public:
-  PreeditArea();
+  PreeditArea(QWidget* parent = 0);
   virtual ~PreeditArea() { }
 
   void setFont(const QFont &);
-  void showInputingString(const QString& str, uint caret_pos);
-  void showConvertingSegments(const QStringList& strlist, uint attention=0);
-  void showChangingSegmentLength(const QStringList& strlist, uint attention=0);
+  void showInputingString(const QString& str, int caret_pos);
+  void showConvertingSegments(const QStringList& strlist, int attention=0);
+  void showChangingSegmentLength(const QStringList& strlist, int attention=0);
   void movePreeditPos(const QPoint& pos);
   QString text() const;
   QString backwardText() const;
@@ -27,7 +23,6 @@ public:
   QString forwardText() const;
 
 public slots:
-  void polish();
   void init();
   void adjustSize();
   void hide();
@@ -36,7 +31,7 @@ signals:
   void listPointChanged(const QPoint& pos);
 
 protected:
-  void showText(const QStringList& strlist, uint attention, uint caret_pos=0);
+  void showText(const QStringList& strlist, int attention, int caret_pos=0);
   void readColorSetting();
 
 private:
