@@ -13,6 +13,7 @@
 #include <QMessageBox>
 #include <QDesktopWidget>
 #include <QHeaderView>
+#include <QSystemTrayIcon>
 #include <sys/utsname.h>
 using namespace Kimera;
 
@@ -135,7 +136,7 @@ PropertyDialog::PropertyDialog(QWidget* parent) : QDialog(parent)
   _ui._lblaboutkimera->setText(tr("<p align=\"center\"><font size=\"+3\"><i>Kimera</i></font><br>"
                                   "Version " KIMERA_VERSION "</p>"
                                   "%1"
-                                  "<p align=\"center\">Copyright (c) 2003-2008  AOYAMA Kazz<br>"
+                                  "<p align=\"center\">Copyright (c) 2003-2009  AOYAMA Kazz<br>"
                                   "<a href=\"http://kimera.sourceforge.jp/\">http://kimera.sourceforge.jp/</a></p>"
                                   "<p align=\"center\">This program is distributed under the terms of "
                                   "the GNU GENERAL PUBLIC LICENSE Version 3.</p>").arg(sysname));
@@ -163,6 +164,7 @@ PropertyDialog::PropertyDialog(QWidget* parent) : QDialog(parent)
   connect(_ui._cmbkanjieng, SIGNAL(activated(QString)), this, SLOT(slotKanjiEngineActivated(QString)));
   connect(_ui._cmdselectbtn, SIGNAL(clicked()), this, SLOT(slotFileSelection()));
   connect(_ui._colorsetting, SIGNAL(cellClicked(int,int)), this, SLOT(changeColor(int,int)));
+  connect(_ui._chktrayicon, SIGNAL(toggled(bool)), _ui._chkdispbar, SLOT(setDisabled(bool)));
 }
 
 
@@ -175,7 +177,8 @@ void PropertyDialog::loadSetting()
                                                                                    _ui._cmbinputmode->currentText())));
   _ui._cmbinputstyle->setCurrentIndex(_ui._cmbinputstyle->findText(Config::readEntry("_cmbinputstyle", 
                                                                                      _ui._cmbinputstyle->currentText())));
-  _ui._chkdispbar->setChecked(Config::readBoolEntry("_chkdispbar", FALSE));
+  _ui._chkdispbar->setChecked(Config::readBoolEntry("_chkdispbar", false));
+  _ui._chktrayicon->setChecked(Config::readBoolEntry("_chktrayicon", false));
   
   _ui._cmbspacekey->setCurrentIndex(_ui._cmbspacekey->findText(Config::readEntry("_cmbspacekey",
                                                                                  _ui._cmbspacekey->currentText())));
@@ -234,7 +237,7 @@ bool PropertyDialog::saveSetting()
 			   QMessageBox::Ok | QMessageBox::Default, 0);
 
       _ui._tabwdg->setCurrentWidget(_ui._tab3);  // show page
-      return FALSE;
+      return false;
       
     } else if ( !_ui._edtport->text().contains(QRegExp("^[0-9]{4,5}$")) ) {
       QMessageBox::warning(this, "Incorrect port number", 
@@ -242,7 +245,7 @@ bool PropertyDialog::saveSetting()
 			   QMessageBox::Ok | QMessageBox::Default, 0);
      
       _ui._tabwdg->setCurrentWidget(_ui._tab3);  // show page
-      return FALSE;
+      return false;
     }
   }
   
@@ -252,6 +255,7 @@ bool PropertyDialog::saveSetting()
   Config::writeEntry("_cmbinputmode", _ui._cmbinputmode->currentText());
   Config::writeEntry("_cmbinputstyle", _ui._cmbinputstyle->currentText());
   Config::writeEntry("_chkdispbar", _ui._chkdispbar->isChecked());
+  Config::writeEntry("_chktrayicon", _ui._chktrayicon->isChecked());
 
   Config::writeEntry("_cmbspacekey", _ui._cmbspacekey->currentText());
   Config::writeEntry("_cmbtenkey", _ui._cmbtenkey->currentText());
@@ -281,7 +285,7 @@ bool PropertyDialog::saveSetting()
   }
   
   emit settingChanged();
-  return TRUE;
+  return true;
 }
 
 
@@ -419,39 +423,40 @@ void PropertyDialog::saveDefaultSetting()
 {
   DEBUG_TRACEFUNC();
 
-  Config::writeEntry("_cmbstartkey", tr("Zenkaku_Hankaku"), FALSE);
-  Config::writeEntry("_cmbinputmode", tr("Ҥ餬"), FALSE);
-  Config::writeEntry("_cmbinputstyle", tr("޻"), FALSE);
-  Config::writeEntry("_chkdispbar", FALSE, FALSE);
-  
-  Config::writeEntry("_cmbspacekey", tr("ϥ⡼ɤ˽"), FALSE);
-  Config::writeEntry("_cmbtenkey", tr("ϥ⡼ɤ˽"), FALSE);
-  Config::writeEntry("_cmbtouten", tr(""), FALSE);
-  Config::writeEntry("_cmbkuten", tr(""), FALSE);
-  Config::writeEntry("_cmbsymbol", tr(""), FALSE);
-  Config::writeEntry("_cmbbracket", tr("֡"), FALSE);
+  Config::writeEntry("_cmbstartkey", tr("Zenkaku_Hankaku"), false);
+  Config::writeEntry("_cmbinputmode", tr("Ҥ餬"), false);
+  Config::writeEntry("_cmbinputstyle", tr("޻"), false);
+  Config::writeEntry("_chkdispbar", false, false);
+  Config::writeEntry("_chktrayicon", false, false);
 
-  Config::writeEntry("_cmbkanjieng", tr( DEFAULT_KANJIENGINE ), FALSE);
-  Config::writeEntry("_grpremote", FALSE, FALSE);
-  Config::writeEntry("_edtsvrname", QString::null, FALSE);
-  Config::writeEntry("_edtport", QString::null, FALSE);
-  Config::writeEntry("_grppredict", FALSE, FALSE);
-  Config::writeEntry("_cmbpredict", tr("Anthy"), FALSE);
+  Config::writeEntry("_cmbspacekey", tr("ϥ⡼ɤ˽"), false);
+  Config::writeEntry("_cmbtenkey", tr("ϥ⡼ɤ˽"), false);
+  Config::writeEntry("_cmbtouten", tr(""), false);
+  Config::writeEntry("_cmbkuten", tr(""), false);
+  Config::writeEntry("_cmbsymbol", tr(""), false);
+  Config::writeEntry("_cmbbracket", tr("֡"), false);
 
-  Config::writeEntry("_cmbcmd", QString::null, FALSE);
+  Config::writeEntry("_cmbkanjieng", tr( DEFAULT_KANJIENGINE ), false);
+  Config::writeEntry("_grpremote", false, false);
+  Config::writeEntry("_edtsvrname", QString::null, false);
+  Config::writeEntry("_edtport", QString::null, false);
+  Config::writeEntry("_grppredict", false, false);
+  Config::writeEntry("_cmbpredict", tr("Anthy"), false);
+
+  Config::writeEntry("_cmbcmd", QString::null, false);
 
   // Saves default color table items
   const int setting = ST_MSIME;
-  Config::writeEntry("_cmbloadcolor", setting, FALSE);
+  Config::writeEntry("_cmbloadcolor", setting, false);
   int i, j;
   for (i = 0; i < NUM_ROWS; i++) {
     for (j = 0; j < NUM_COLS - 1; j++) {
       Config::writeEntry(QString("_colorsettingcolor") + QString::number(i) + '-' + QString::number(j),
-			 ColorSetting[setting][i][j], FALSE);
+			 ColorSetting[setting][i][j], false);
     }
     
     Config::writeEntry(QString("_colorsettingunderline") + QString::number(i), 
-		       ColorSetting[setting][i][j], FALSE);
+		       ColorSetting[setting][i][j], false);
   }
 }
 
@@ -464,7 +469,7 @@ void PropertyDialog::slotKanjiEngineActivated( const QString & string )
   if (eng) {
     _ui._grpremote->setEnabled(eng->isTCPConnectionSupported());
   } else {
-    _ui._grpremote->setEnabled(FALSE);
+    _ui._grpremote->setEnabled(false);
   }
 }
 
