@@ -4,7 +4,7 @@
 #include <QDir>
 
 TomoeEngine::TomoeEngine()
-  : _tomoe(new QProcess(this))
+  : _tomoe(new QProcess(0))
 {
   connect(_tomoe, SIGNAL(readyReadStandardOutput()), this, SLOT(readFromStdout()));
 }
