@@ -13,15 +13,15 @@ public:
   ~TomoeEngine();
   
   QString name() const;
-  bool isKanjiConvEnabled() const { return FALSE; }
+  bool isKanjiConvEnabled() const { return false; }
 
   bool  init();
   void  cleanup();
   bool  beginConvert(const QString& hira, QStringList& kanji, QStringList& yomigana);
-  void  endConvert(const QStringList& kanji=QString::null);
+  void  endConvert(const QStringList& kanji=QStringList());
   bool  getCandidate(int idx, QStringList& candidate);
   bool  resizeSegment(int idx, int len, QStringList& kanji, QStringList& yomigana);
-  bool  isConverting() { return FALSE; }
+  bool  isConverting() { return false; }
 
 protected slots:
   void  readFromStdout();
