@@ -42,13 +42,11 @@ XIContext::getSuppICAttr()
 
 XIContext::XIContext()
 {
-  //_iclist.setAutoDelete(TRUE);
 }
 
 
 XIContext::~XIContext()
 {
-
 }
 
 
@@ -73,7 +71,7 @@ XIContext::removeIC(quint16 ic)
 void
 XIContext::setValue(quint16 ic, quint16 id, const QByteArray& data)
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   if ( pxic ) pxic->setValue(id, data);
 }
 
@@ -81,7 +79,7 @@ XIContext::setValue(quint16 ic, quint16 id, const QByteArray& data)
 QByteArray
 XIContext::getValue(quint16 ic, quint16 id) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->getValue(id) : QByteArray();
 }
 
@@ -89,7 +87,7 @@ XIContext::getValue(quint16 ic, quint16 id) const
 XIMStyle
 XIContext::inputStyle(quint16 ic) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->inputStyle() : 0;
 }
 
@@ -97,7 +95,7 @@ XIContext::inputStyle(quint16 ic) const
 Window
 XIContext::focusWindow(quint16 ic) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->focusWindow() : 0;
 }
 
@@ -105,7 +103,7 @@ XIContext::focusWindow(quint16 ic) const
 QString
 XIContext::fontPreedit(quint16 ic) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->fontPreedit() : QString();
 }
 
@@ -113,7 +111,7 @@ XIContext::fontPreedit(quint16 ic) const
 void
 XIContext::setSpotPreedit(quint16 ic, const QPoint& p)
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   if ( pxic ) pxic->setSpotPreedit( p );
 }
 
@@ -121,7 +119,7 @@ XIContext::setSpotPreedit(quint16 ic, const QPoint& p)
 QPoint
 XIContext::spotPreedit(quint16 ic) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->spotPreedit() : QPoint();
 }
 
@@ -129,7 +127,7 @@ XIContext::spotPreedit(quint16 ic) const
 bool
 XIContext::ximPreeditStarted(quint16 ic) const
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   return pxic ? pxic->ximPreeditStarted() : FALSE;
 }
 
@@ -137,7 +135,7 @@ XIContext::ximPreeditStarted(quint16 ic) const
 void
 XIContext::setXIMPreeditStarted(quint16 ic, bool b)
 {
-  XICAttribute* pxic = _iclist[ic];
+  XICAttribute* pxic = _iclist.value(ic);
   if ( pxic ) pxic->setXIMPreeditStarted( b );
 }
 
