@@ -74,7 +74,7 @@ XIMethod::createIM(Window w)
 void
 XIMethod::removeIM(quint16 im)
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   if ( pxim ) {
     _disconnect_wins << pxim->commWin();
     delete _imlist.take( im );
@@ -86,7 +86,7 @@ XIMethod::removeIM(quint16 im)
 quint16
 XIMethod::createXIC(quint16 im)
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->_xic.createIC() : 0;
 }
 
@@ -94,7 +94,7 @@ XIMethod::createXIC(quint16 im)
 void
 XIMethod::removeXIC(quint16 im, quint16 ic)
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   if ( pxim ) {
     pxim->_xic.removeIC(ic);
   }
@@ -107,7 +107,7 @@ XIMethod::setICValue(quint16 im, quint16 ic, quint16 id, const QByteArray& data)
   qDebug("%s: IM:%d IC:%d attributes-id:%d data-size:%d",
 	 __func__, im, ic, id, data.size());
 
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   if ( pxim )
     pxim->_xic.setValue(ic, id, data);
 }
@@ -117,7 +117,7 @@ QByteArray
 XIMethod::getICValue(quint16 im, quint16 ic, quint16 id)
 {
   qDebug("%s: IM:%d IC:%d attributes-id:%d", __func__, im, ic, id);
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->_xic.getValue(ic, id) : QByteArray();
 }
 
@@ -125,7 +125,7 @@ XIMethod::getICValue(quint16 im, quint16 ic, quint16 id)
 QString
 XIMethod::fontPreedit(quint16 im, quint16 ic)
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->_xic.fontPreedit(ic) : QString();
 }
 
@@ -133,7 +133,7 @@ XIMethod::fontPreedit(quint16 im, quint16 ic)
 void
 XIMethod::setSpotPreedit(quint16 im, quint16 ic, const QPoint& p)
 {
-  XIMAttribute*  pxim = _imlist[im];
+  XIMAttribute*  pxim = _imlist.value(im);
   if ( pxim ) {
     pxim->_xic.setSpotPreedit(ic, p);
   }
@@ -143,7 +143,7 @@ XIMethod::setSpotPreedit(quint16 im, quint16 ic, const QPoint& p)
 QPoint
 XIMethod::spotPreedit(quint16 im, quint16 ic)
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->_xic.spotPreedit(ic) : QPoint();
 }
 
@@ -151,7 +151,7 @@ XIMethod::spotPreedit(quint16 im, quint16 ic)
 Window
 XIMethod::commWin(quint16 im) const
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->commWin() : 0;
 }
 
@@ -159,7 +159,7 @@ XIMethod::commWin(quint16 im) const
 Window
 XIMethod::focusWindow(quint16 im, quint16 ic) const
 {
-  XIMAttribute* pxim = _imlist[im];
+  XIMAttribute* pxim = _imlist.value(im);
   return pxim ? pxim->_xic.focusWindow(ic) : 0;
 }
 
@@ -168,7 +168,7 @@ XIMethod::focusWindow(quint16 im, quint16 ic) const
 XIMStyle
 XIMethod::getInputStyle(quint16 im, quint16 ic) const
 {
-  XIMAttribute*  pxim = _imlist[im];
+  XIMAttribute*  pxim = _imlist.value(im);
   return pxim ? pxim->_xic.inputStyle(ic) : 0;
 }
 
@@ -189,7 +189,7 @@ XIMethod::queryInputStyle() const
 void
 XIMethod::setXIMPreeditStarted(quint16 im, quint16 ic, bool b)
 {
-  XIMAttribute*  pxim = _imlist[im];
+  XIMAttribute*  pxim = _imlist.value(im);
   if ( pxim ) {
     pxim->_xic.setXIMPreeditStarted(ic, b);
   }
@@ -199,7 +199,7 @@ XIMethod::setXIMPreeditStarted(quint16 im, quint16 ic, bool b)
 bool
 XIMethod::ximPreeditStarted(quint16 im, quint16 ic) const
 {
-  XIMAttribute*  pxim = _imlist[im];
+  XIMAttribute*  pxim = _imlist.value(im);
   return pxim ? pxim->_xic.ximPreeditStarted(ic) : FALSE;
 }
 
@@ -220,7 +220,7 @@ XIMethod::getIMList() const
 QList<quint16>
 XIMethod::getICList(quint16 im) const
 {
-  XIMAttribute*  pxim = _imlist[im];
+  XIMAttribute*  pxim = _imlist.value(im);
   return pxim ? pxim->xic().icList() : QList<quint16>();
 }
 
